@@ -1,5 +1,5 @@
 package Plack::Middleware::Debug::HTML::Mason;
-$Plack::Middleware::Debug::HTML::Mason::VERSION = '0.2';
+$Plack::Middleware::Debug::HTML::Mason::VERSION = '0.3';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Plack::Middleware::Debug::HTML::Mason - Debug info for old HTML::Mason apps.
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
@@ -24,7 +24,20 @@ version 0.2
 =head1 DESCRIPTION
 
 Provides a call tree and some basic configuration information for a request
-processed by HTML::Mason.
+processed by HTML::Mason.  To use this panel the included plugin
+C<Plack::Middleware::Debug::HTML::Mason::Plugin> must be called by Mason.  If
+this panel is enabled, the C<psgi.middleware.debug.htmlmason> key will be set
+in the psgi environment.  This might be useful if you want load the plugin as
+needed:
+
+		if ($env->{'psgi.middleware.debug.htmlmason'}) {
+			$handler->interp->plugins(['Plack::Middleware::Debug::HTML::Mason::Plugin']);
+		}
+		else {
+			$handler->interp->plugins([]);
+		}
+		
+		...
 
 =cut
 
@@ -90,6 +103,7 @@ sub run {
 	@stack = ();
 	%env   = ();
 	$ran   = 0;
+	$env->{'psgi.middleware.debug.htmlmason'} = 1;
 	
 	return sub {
 		my $res = shift;
@@ -203,8 +217,5 @@ L<Plack::Middleware::Debug>, L<HTML::Mason>, perl(1)
 =cut
 
 1;
-$Plack::Middleware::Debug::HTML::Mason::Plugin::VERSION = '0.2';
-__END__
-
-1;
+$Plack::Middleware::Debug::HTML::Mason::Plugin::VERSION = '0.3';
 __END__
